#ifndef GEISSINGLETON_H
#define GEISSINGLETON_H

#include "gesture.h"
#include "gesturearea.h"

#include <geis/geis.h>

#include <QObject>
#include <QHash>
#include <QMultiMap>

class QSocketNotifier;
class GestureArea;

class GeisSingleton : public QObject
{
    Q_OBJECT
public:
    explicit GeisSingleton(QObject *parent = 0);
    ~GeisSingleton();

    static GeisSingleton *instance();

    Geis geis() const { return _geis; };
    bool isInitialized() const { return _initialized; };
    void registerGestureArea(const GestureArea *area);

signals:
    void initialized();

private:
    Geis _geis;
    bool _initialized;
    QSocketNotifier *_notifier;
    QHash<GestureArea::Primitive, GeisGestureClass> _classes;
    QHash<GeisGestureId, QMap<GestureArea::Primitive, GestureArea *> > _activeGestures;
    QMultiHash<WId, const GestureArea *> _windowMap;
    QHash<GeisInteger, Gesture::DeviceType> _deviceTypeMap;

    template <typename Ret, typename Object>
    static Ret getAttribute(Object object, const char *attributeName);

    static QPointF pointForTouch(GeisTouch touch);
    static QRectF rectForTouches(const QSet<GeisTouch> &touches);
    static QRectF rectForFocus(GeisFrame frame);
    static bool containsClaimedTouches(const QSet<GeisTouch> &touches, const QSet<GeisTouch> &claimedTouches);
    static bool containsOtherUnclaimedTouches(const GestureArea *area, const QSet<GeisTouch> &touches, const QSet<GeisTouch> &unclaimedTouches);

    void handleClassEvent(GeisEvent event);
    void handleDeviceEvent(GeisEvent event);
    void handleGestureBeginEvent(GeisEvent event);
    void handleGestureUpdateEvent(GeisEvent event, bool end);
    void getGestureFrameList(GeisGroupSet groupSet, QList<GeisFrame> &frames);
    QGraphicsScene *findSceneForTouches(WId window, const QRectF &touches);

private slots:
    void geisEvent();
};

#endif // GEISSINGLETON_H
