#include "gesture.h"
#include "geissingleton.h"

Gesture::Gesture(QDeclarativeItem *parent) :
    QDeclarativeItem(parent),
    _touches(this),
    _devices(All),
    _subscription(NULL)
{
}

void Gesture::setDevices(Gesture::DeviceType newValue)
{
    if (_devices != newValue) {
        _devices = newValue;
        emit devicesChanged();
    }
}

void Gesture::setSubscription(GeisSubscription subscription)
{
    deleteSubscription();
    _subscription = subscription;
}

bool Gesture::enableSubscription()
{
    GeisStatus status;

    if (!_subscription) {
        qWarning("Attempted to enable non-existent subscription");
        return false;
    }

    status = geis_subscription_activate(_subscription);
    if (status != GEIS_STATUS_SUCCESS) {
        qWarning("Failed to enable subscription");
        return false;
    }

    return true;
}

bool Gesture::disableSubscription()
{
    GeisStatus status;

    if (!_subscription) {
        qWarning("Attempted to disable non-existent subscription");
        return false;
    }

    status = geis_subscription_deactivate(_subscription);
    if (status != GEIS_STATUS_SUCCESS) {
        qWarning("Failed to disable subscription");
        return false;
    }

    return true;
}

void Gesture::deleteSubscription()
{
    if (_subscription)
        geis_subscription_delete(_subscription);
    _subscription = NULL;
}

Gesture::~Gesture()
{
    deleteSubscription();
}

TouchLimits::TouchLimits(QObject *parent) :
    QObject(parent),
    _start(2)
{
}

void TouchLimits::setStart(int newValue)
{
    if (_start != newValue) {
        _start = newValue;
        emit startChanged();
    }
}
