#include "gestureevent.h"
#include "gesturearea.h"

GestureEvent::GestureEvent(GestureArea *area, GeisFrame frame, GeisTouchSet touchSet) :
    QDeclarativeItem(area),
    _gesture(area->getSubscription()),
    _accepted(true)
{
    for (GeisSize i = 0; i < geis_frame_attr_count(frame); i++) {
        GeisAttr attr;
        GeisString name;

        attr = geis_frame_attr(frame, i);
        if (!attr) {
            qCritical("Warning: Failed to get frame attribute");
            continue;
        }

        name = geis_attr_name(attr);
        if (!name) {
            qCritical("Warning: Failed to get name of attribute");
            continue;
        }

        switch (geis_attr_type(attr)) {
        case GEIS_ATTR_TYPE_BOOLEAN:
            _attributes[name] = QVariant((bool)geis_attr_value_to_boolean(attr));
            break;
        case GEIS_ATTR_TYPE_FLOAT:
            _attributes[name] = QVariant((float)geis_attr_value_to_float(attr));
            break;
        case GEIS_ATTR_TYPE_INTEGER:
            _attributes[name] = QVariant((int)geis_attr_value_to_integer(attr));
            break;
        case GEIS_ATTR_TYPE_STRING:
            _attributes[name] = QVariant(QString(geis_attr_value_to_string(attr)));
            break;
        default: // Unknown or pointer attribute
            break;
        }
    }

    _id = geis_frame_id(frame);

    for (GeisSize i = 0; i < geis_frame_touchid_count(frame); i++) {
        GeisTouchId touchId;
        GeisTouch geisTouch;

        touchId = geis_frame_touchid(frame, i);
        geisTouch = geis_touchset_touch_by_id(touchSet, touchId);

        _touches.append(new Touch(geisTouch, this));
    }
}

void GestureEvent::setAccepted(bool newValue)
{
    if (_accepted != newValue) {
        _accepted = newValue;
        emit acceptedChanged();
    }
}
