#include "touch.h"

Touch::Touch(GeisTouch touch, QDeclarativeItem *parent) :
    QDeclarativeItem(parent),
    _id(0),
    _location(0, 0)
{
    GeisFloat x;
    GeisFloat y;

    if (!touch)
        return;

    for (GeisSize i = 0; i < geis_touch_attr_count(touch); i++) {
        GeisAttr attr;
        GeisString name;

        attr = geis_touch_attr(touch, i);
        if (!attr) {
            qCritical("Warning: Failed to get frame attribute");
            continue;
        }

        name = geis_attr_name(attr);
        if (!name) {
            qCritical("Warning: Failed to get name of attribute");
            continue;
        }

        switch (geis_attr_type(attr)) {
        case GEIS_ATTR_TYPE_BOOLEAN:
            _attributes.insert(QString(name), QVariant((bool)geis_attr_value_to_boolean(attr)));
            break;
        case GEIS_ATTR_TYPE_FLOAT:
            _attributes.insert(QString(name), QVariant((float)geis_attr_value_to_float(attr)));
            break;
        case GEIS_ATTR_TYPE_INTEGER:
            _attributes.insert(QString(name), QVariant((int)geis_attr_value_to_integer(attr)));
            break;
        case GEIS_ATTR_TYPE_STRING:
            _attributes.insert(QString(name), QVariant(QString(geis_attr_value_to_string(attr))));
            break;
        default: // Unknown or pointer attribute
            break;
        }
    }

    _id = _attributes[GEIS_TOUCH_ATTRIBUTE_ID].toInt();

    x = _attributes[GEIS_TOUCH_ATTRIBUTE_X].toFloat();
    y = _attributes[GEIS_TOUCH_ATTRIBUTE_Y].toFloat();
    _location.setX(x);
    _location.setX(y);
}
