#ifndef TOUCH_H
#define TOUCH_H

#include <geis/geis.h>

#include <QtDeclarative/QDeclarativeItem>

/**
 * An item that provides information about a touch point.
 */

class Touch : public QDeclarativeItem
{
    Q_OBJECT
    Q_DISABLE_COPY(Touch)

    /**
     * This property holds the ID of the touch.
     */
    Q_PROPERTY(int id READ getId)

    /**
     * This property holds the coordinates of the touch.
     *
     * For Indirect and Independent devices, the value is in device coordinates.
     * For Direct devices, the value is in screen coordinates.
     */
    Q_PROPERTY(QPointF location READ getLocation)

    /**
     * This property holds a variant map of attributes of the touch.
     *
     * All uTouch touch attributes are available in this property. The keys may
     * be referenced in the geis.h header file.
     */
    Q_PROPERTY(const QVariantMap attributes READ getAttributes)

public:
    explicit Touch() { throw; } /* To satisfy QML */
    explicit Touch(GeisTouch touch, QDeclarativeItem *parent);

    int getId() const { return _id; };
    QPointF getLocation() const { return _location; };
    const QVariantMap getAttributes() const { return _attributes; };

private:
    int _id;
    QPointF _location;
    QVariantMap _attributes;
};

QML_DECLARE_TYPE(Touch)

#endif // TOUCH_H
